Coverage for src/castep_linter/tests/__init__.py: 100%

1""""Tests to be performed by the CASTEP Fortran linter"""

2 from castep_linter.tests.allocate_stat_checked import check_allocate_has_stat

3 from castep_linter.tests.complex_has_dp import check_complex_has_dp

4 from castep_linter.tests.has_trace_entry_exit import test_trace_entry_exit

5 from castep_linter.tests.number_literal_correct_kind import test_number_literal

6 from castep_linter.tests.real_declaration_has_dp import check_real_dp_declaration

7

8 test_list = {

9 "variable_declaration": [check_real_dp_declaration],

10 "subroutine": [test_trace_entry_exit],

11 "function": [test_trace_entry_exit],

12 "call_expression": [check_complex_has_dp, check_allocate_has_stat],

13 "number_literal": [test_number_literal],

14}